# -*- mode: rpm-spec; coding: utf-8 -*-

# if we want to have logging support in or not.
%def_with syslog

# if we want to enable debugging support in udev.  If it is enabled, lots of
# stuff will get sent to the debug syslog.
%def_with debug

Name: udev
Version: 108
Release: alt2.M40.1

Summary: udev - an userspace implementation of devfs
Summary(ru_RU.UTF-8): udev - это вынесенная из ядра реализация devfs
License: GPL
Group: System/Configuration/Hardware
Url: http://kernel.org/pub/linux/utils/kernel/hotplug/

BuildRequires: klibc-devel

Source0: %name-%version.tar

Patch0: %name-%version-%release.patch

PreReq: shadow-utils
PreReq: module-init-tools >= 3.3
PreReq: dmsetup
PreReq: libvolume_id = %version-%release
PreReq: %name-rules = %version-%release

Requires: udev_static-addon

Conflicts: linux-hotplug

# Find dependencies on klibc-*.so
%global __find_requires %_libdir/klibc/klibc-find-requires %__find_requires

%description
Starting with the 2.5 kernel, all physical and virtual devices in a
system are visible to userspace in a hierarchal fashion through
sysfs. /sbin/hotplug provides a notification to userspace when any
device is added or removed from the system. Using these two features,
a userspace implementation of a dynamic /dev is now possible that can
provide a very flexible device naming policy.

%description -l ru_RU.UTF-8
Начиная с ядра 2.5, все реальные и виртуальные устройства в системе
имеют иерархическое отображение в sysfs, доступное обычным программам.
/sbin/hotplug информирует программы о том, что устройство подключено
или удалено из системы. Комбинация этих двух подсистем делает возможным
создание динамического /dev, который бы допускал очень гибкую систему
правил наименования устройств.

%package rules
Summary: Rule files for udev
Summary(ru_RU.UTF-8): Файлы правил для udev
Group: System/Configuration/Hardware

Provides: %_sysconfdir/udev/rules.d
Provides: %_sysconfdir/udev/initramfs-rules.d

Conflicts: %name < %version-%release

%description rules
This package contains the default set of rule files used by udev,
which control names and permission of device files in /dev.  Rule
files which have corresponding symlinks in /etc/udev/initramfs-rules.d
are also used by the mkinitrd package when creating initramfs images.

%description -l ru_RU.UTF-8 rules
Этот пакет содержит основной набор правил для udev, управляющих
назначением имён и прав доступа для файлов устройств в /dev.
Часть файлов правил, для которых есть символические ссылки в
каталоге /etc/udev/initramfs-rules.d, также используется пакетом
mkinitrd при создании образов initramfs.

%package -n libvolume_id
Summary: Shared libraries for volume_id
Group: System/Libraries

%description -n libvolume_id
This package provides shared libraries for volume_id.

%package -n libvolume_id-devel
Summary: Libraries and headers for libvolume_id
Group: Development/C
Requires: libvolume_id = %version-%release

%description -n libvolume_id-devel
Headers for libvolume_id.

%package initramfs
Summary: udev built with klibc for use in initramfs
Group: System/Kernel and hardware

# This avoids getting a dependency on sh from "#!/bin/sh".
AutoReq: yes, nopam, noperl, nopython, noshell, notcl

PreReq: mkinitrd-initramfs
Requires: klibc-utils-initramfs
Requires: %name-rules = %version-%release

%description initramfs
This package contains a version of udev which is built with klibc,
intended for use in initramfs images generated by mkinitrd.

%prep
%setup -q -c
cd %name-%version
%patch0 -p1
cd ..
cp -pr %name-%version build-klibc
mv %name-%version/* ./

%build
# udev doesn't support parallel build yet
NPROCS=1
export NPROCS

# Build normal version
%make_build \
	USE_LOG=%{?_with_syslog:true}%{!?_with_syslog:false} \
	DEBUG=%{?_with_debug:true}%{!?_with_debug:false} \
	udevdir=/dev

for i in extras/path_id extras/floppy extras/usb_id extras/scsi_id extras/ata_id extras/edd_id extras/cdrom_id extras/firmware extras/floppy extras/volume_id/ ; do \
    %make_build  udevdir=/dev EXTRAS=$i
done

# Build with klibc (for initramfs)
cd build-klibc
%make_build USE_LOG=false DEBUG=false udevdir=/dev \
	CC=klcc LD="klcc -shared" SHLIB= \
	EXTRAS="extras/ata_id extras/cdrom_id extras/edd_id extras/path_id extras/scsi_id extras/usb_id extras/volume_id"
cd ..

%install
%__make DESTDIR=%buildroot \
	initdir=%_initdir \
	install

# Make /dev default for udev_root and udev_db
%__subst 's/^\(udev_root=\).*/\1"\/dev"/g' %buildroot%_sysconfdir/udev/udev.conf
%__subst 's/^\(udev_db=\)"?.*\([^\/]+\)"?$/\1"\/dev\/\2"/g' %buildroot%_sysconfdir/udev/udev.conf

cat >>%buildroot%_sysconfdir/udev/udev.conf <<EOF
# Whether to mount a tmpfs filesystem to \$udev_root
udev_tmpfs="1"

# tmpfs options. Note that size shouldn't be less than several
# megabytes due to insane format of current udev database
# (in /dev/.udevdb)
tmpfs_options="size=5m"
EOF

%__mkdir_p %buildroot%_initdir
%__rm -f %buildroot%_initdir/udev
install -m 0755 etc/init.d/udevd.init %buildroot%_initdir/udevd
install -m 0755 etc/init.d/udevd-final.init %buildroot%_initdir/udevd-final

%__mkdir_p %buildroot%_sysconfdir/udev/devices

for i in extras/path_id extras/floppy extras/usb_id extras/scsi_id extras/ata_id extras/edd_id extras/cdrom_id extras/firmware extras/floppy extras/volume_id/ ; do \
    %make udevdir=/dev EXTRAS=$i DESTDIR=%buildroot libdir=/%_lib usrlibdir=%_libdir install
done

install -m 0755 extras/dm_helper/dm_helper %buildroot/lib/udev/
install -m 0755 extras/hotplug/*.agent %buildroot/lib/udev/

%__rm -f %buildroot%_sysconfdir/udev/udev.permissions
%__rm -f %buildroot%_sysconfdir/udev/udev.rules.devfs

%__rm -f %buildroot%_sysconfdir/udev/permissions.d/50-udev.permissions
%__rm -f %buildroot%_sysconfdir/udev/rules.d/*
%__install -m 644 etc/udev/altlinux/* %buildroot%_sysconfdir/udev/rules.d/

install -d %buildroot/%_sysconfdir/dev.d/default

# Install klibc version
cd build-klibc
mkdir -p %buildroot/lib/mkinitrd/udev/sbin
install -p udevd udevtrigger udevsettle %buildroot/lib/mkinitrd/udev/sbin/
mkdir -p %buildroot/lib/mkinitrd/udev/lib/udev
install -p \
	extras/ata_id/ata_id \
	extras/cdrom_id/cdrom_id \
	extras/edd_id/edd_id \
	extras/firmware/firmware.sh \
	extras/path_id/path_id \
	extras/scsi_id/scsi_id \
	extras/usb_id/usb_id \
	extras/volume_id/vol_id \
	%buildroot/lib/mkinitrd/udev/lib/udev/
cd ..

# Install symlinks for rules which are needed in initramfs
mkdir -p %buildroot%_sysconfdir/udev/initramfs-rules.d
for f in \
	05-udev-early.rules \
	20-hotplug-modprobe.rules \
	50-udev-default.rules \
	60-persistent-storage.rules \
	63-md.rules \
	64-device-mapper.rules \
	70-permissions.rules
do
	ln -s ../rules.d/"$f" \
		%buildroot%_sysconfdir/udev/initramfs-rules.d/"$f"
done

%pre
/usr/sbin/groupadd -r -f video

if [ $1 -gt 1 ] && [ -d /dev/.udev ]; then
	rm -f /dev/.udev/old_version ||:
	old_ver="$(/sbin/udevd --version 2>/dev/null)" || old_ver=
	[ -n "$old_ver" ] ||
		old_ver="$(/usr/bin/udevinfo --version 2>/dev/null)" ||
		old_ver=
	old_ver="${old_ver##*[!0-9]}"
	[ -z "$old_ver" ] ||
		printf '%%s\n' "$old_ver" >/dev/.udev/old_version ||:
fi

%post
old_ver=
if [ $1 -gt 1 ]; then
	udevd_stopped="$(/sbin/service udevd status | grep stopped)" ||:
	if [ -z "$udevd_stopped" ]; then
		old_ver="$(cat /dev/.udev/old_version 2>/dev/null)" || old_ver=
	fi
	rm -f /dev/.udev/old_version 2>/dev/null ||:
fi
if [ -n "$old_ver" ]; then
	/sbin/service udevd stop ||:
	/usr/sbin/udevconvertdb -f "$old_ver" ||
		echo "Warning: udev database conversion failed - probably a reboot is required" >&2
fi

%post_service udevd

if [ -n "$old_ver" ]; then
	/sbin/service udevd start_udevd_only ||:
fi

%post_service udevd-final

%preun
%preun_service udevd
%preun_service udevd-final

%triggerpostun -- udev < 105
# %%post_service will skip chkconfig --add on upgrade and run resetpriorities
# instead, which turns the service off when it was not added before.
/sbin/chkconfig --add udevd-final ||:
/sbin/chkconfig udevd-final reset ||:

%files -n libvolume_id
/%_lib/*.so.*

%files -n libvolume_id-devel
%_includedir/*
%_libdir/*.so
%_pkgconfigdir/*.pc

%files
%doc COPYING README TODO ChangeLog RELEASE-NOTES
%doc docs/overview docs/udev_vs_devfs
%doc docs/writing_udev_rules/*
%_sysconfdir/dev.d
%attr(0755,root,root) %_initdir/udevd
%attr(0755,root,root) %_initdir/udevd-final
%dir /lib/udev
/lib/udev/*
%config(noreplace) %_sysconfdir/udev/*.conf
%dir %_sysconfdir/udev/devices
%config %_sysconfdir/scsi_id.config
/sbin/*
%_sbindir/*
%_bindir/*
%attr(-,root,man) %_man8dir/*
%attr(-,root,man) %_man7dir/*

%files rules
%dir %_sysconfdir/udev
%dir %_sysconfdir/udev/rules.d
%config %_sysconfdir/udev/rules.d/*
%dir %_sysconfdir/udev/initramfs-rules.d
%config(noreplace) %_sysconfdir/udev/initramfs-rules.d/*

%files initramfs
/lib/mkinitrd/udev

%changelog
* Thu Apr 09 2009 Valery Inozemtsev <shrek@altlinux.ru> 108-alt2.M40.1
- fixed CVE-2009-1185

* Wed Nov 28 2007 Sergey Vlasov <vsu@altlinux.ru> 108-alt2
- Applied post-108 upstream changes (0809c264e9878cdd1c61d9fb0e077972bc596ef8):
  + make ACTION!="add|change" working (now "!=" is really the inverse of "==")
  + udevinfo: export all information stored in database
  + udevtest: export ACTION string if given as option
  + udevtest: import uevent variables if possible
- Updated udevd initscript:
  + fixed check for /dev/shm entry in fstab
- Updated udev rules:
  + added /dev/js* compat symlinks for /dev/input/js* (#7669)

* Thu Mar 29 2007 Sergey Vlasov <vsu@altlinux.ru> 108-alt1
- New upstream release (108).
- Note: udev_run_devd and udev_run_hotplugd utilities were removed from udev
  by upstream developers (their usage in rules was removed in 105-alt1).
- Reverted create_floppy_devices change from 0.77-alt3 which was adding the
  "-g <group>" option (in udev-106 the "-G <group>" option was added).
- Updated udevd initscript:
  + added "start_udev_only" action for use during package upgrade;
  + removed setting kernel.hotplug to /sbin/hotplug on stop.
- Updated udev rules:
  + updated create_floppy_devices options for new implementation in udev-106;
  + removed useless dasd support (s390 only);
  + added persistent symlinks for SCSI tapes and medium changer devices;
  + fixed WAIT_FOR_SYSFS for SCSI devices;
  + fixed wrong rule for raw devices (/dev/raw/raw[0-9]*);
  + added -b option to all modprobe invocations;
  + disabled MODALIAS autoload for the i82365 module (Debian bug #398962);
  + added SUBSYSTEM and ACTION checks to rules for ALSA devices;
  + added checks to avoid normal rules for net devices (Gentoo bug #166652);
  + added rules to create /dev/disk/{by-uuid,by-label}/* links for md devices
    (63-md.rules); these rules are also copied to initramfs (#11190).
- Added /usr/sbin/udevconvertdb utility to convert udev database to the new
  format used since udev-107; updated %%pre and %%post scripts to convert the
  database during upgrade.

* Mon Feb 19 2007 Sergey Vlasov <vsu@altlinux.ru> 105-alt3
- Added conflicts with old udev packages to the udev-rules subpackage
  (prevents attempts to install udev-rules together with old releases of
  udev which had rule files in the main package).
- Updated udevd initscript:
  + removed broken code which tried to remove old udev database on start;
  + fixed compatibility with startup-0.9.8.9-alt1:
     + pass -n option to mount when running from rc.sysinit;
     + do not try to start another copy of udevd if already running;
     + use $tmpfs_options when mounting /dev initially;
     + do not try to remount /dev when running from rc.sysinit;
     + do not unmount /dev on stop (this time "service udevd umount" added
       for use during dev package upgrade).
     + fix double /dev/shm mounting if it is listed in fstab
- Updated net.agent:
  + check for ignored interface name first (fixes useless failure during
    early startup of interfaces like "lo").

* Sun Feb 11 2007 Sergey Vlasov <vsu@altlinux.ru> 105-alt2
- Fixed net.agent to avoid unwanted dependency on etcnet; now net-scripts
  should be usable again.
- Moved module-init-tools, dmsetup, libvolume_id from Requires to PreReq
  (these packages should be installed before udev to keep rules working).
- Moved rule files to a separate udev-rules package; replaced dependency of
  udev-initramfs on udev with udev-rules (now installing new mkinitrd with
  initramfs support does not require the main udev package).
- Added Provides: /etc/udev/rules.d, /etc/udev/initramfs-rules.d to the
  udev-rules subpackage to be used by other packages with udev rules.
- Updated udevd initscript:
  + do not invoke udevtrigger during restart (avoids bad side effects with
    some devices, but events which happen during restart will be lost)
  + unmount /dev on stop again (reverts the change made in 105-alt1;
    workaround for upgrading the dev package); unmount is not performed on
    restart and condrestart
- Updated udev rules:
  + removed rule for loading the pcmcia module (already in pcmciautils)

* Thu Feb 08 2007 Sergey Vlasov <vsu@altlinux.ru> 105-alt1
- New upstream release (105).
- Dropped git-scsi_id-garbage patch (fixed upstream).
- Replaced old package build system with a new one based on the upstream git
  repository, rewritten spec file for the new layout:
    + applied all old patches as commits in the package git repository
    + placed udev rules in etc/udev/altlinux/
    + placed udevd initscript in etc/init.d/
    + placed dm_helper in extras/dm_helper/
- Added udev-initramfs subpackage which contains udev built with klibc for
  use in initramfs images created by mkinitrd.
- Added /etc/udev/initramfs-rules.d directory containing symlinks to rule
  files which need to be copied to initramfs.
- Disabled recursive substititions in udev_rules_apply_format() (this feature
  is dubious, dangerous if used improperly (e.g., there is no protection from
  infinite loops) and does not seem to be documented properly).
- libvolume_id: Fixed possible buffer overruns when handling romfs and
  ntfs filesystems, and other filesystems with too long labels.
- Updated udev rules:
  + moved rules for ignoring of "drivers" and "module" events from
    20-hotplugd.rules to 05-udev-early.rules
  + fixed rule for removable IDE avoidance to use ATTR{removable} instead of
    ATTRS{removable}
  + added rules to create /dev/disk/{by-uuid,by-label}/* links for devices
    managed by the device mapper driver (64-device-mapper.rules)
  + added rule to invoke /sbin/pam_console_apply in 94-pam-console.rules
    (fixes wrong permissions for devices managed by pam_console if these
    devices appeared after login, or if udevtrigger was rerun)
  + removed callouts to the hotplug package - now modprobe by modalias is
    used to load kernel modules, and other actions are handled by scripts
    included in the udev package (currently net.agent and sound.agent).
- Updated udevd initscript:
  + do not unmount /dev on stop (breaks too much to be useful)
  + implement condrestart instead of ignoring it (now udevd will be
    restarted during package upgrade, like all other daemons)
- Added udevd-final service to perform final steps of udev initialization
  when other parts of the system have been initialized.

* Sun Dec 17 2006 Sergey Vlasov <vsu@altlinux.ru> 103-alt1
- Added patches:
  + git-scsi_id-garbage: scsi_id: remove trailing garbage from ID_SERIAL_SHORT
- Updated udev rules:
  + restore lost rules for firmware loading
  + kill useless NAME="%%k" assignments
  + resync 50-udev-default.rules with SUSE:
     + create /dev/pilot symlink also for Handspring Treo devices
     + create all possible partitions for ide-floppy devices
     + load mmc_block module for MMC devices
     + fix device names for (obsolete) raw devices (/dev/raw/rawN)
     + check for ACTION=="add" when creating /dev/bus/usb/** devices
  + fix permissions for floppy devices (GROUP="floppy", MODE="0660")
  + resync 60-persistent-storage.rules with SUSE:
     + add /dev/disk/by-id/ata-* symlinks for libata and other SAT devices
     + add /dev/disk/by-id/mmc-* symlinks for MMC block devices
  + replace DRIVER key with DRIVERS

* Thu Oct 26 2006 Anton Farygin <rider@altlinux.ru> 103-alt0.1
- Updated patches to new version
- removed patches:
    udev-097-alt-nogroup.patch (included to mainstream)

* Fri Sep 01 2006 Sergey Vlasov <vsu@altlinux.ru> 097-alt2
- Added patches:
  + alt-init-pipe-before-fork: udevd: init signal pipe before forking to
    background
  + alt-udevd-pidfile: udevd: add pid file support (/dev/.udev/udevd.pid)
- Updated udevd initscript:
  + use pid file in /dev/.udev/udevd.pid
  + daemonize with "udevd --daemon" instead of "start_daemon --make-pidfile"
    (should really fix startup race with udevsettle - #9881)
  + revert broken fix for #9881 added in 097-alt1

* Mon Aug 28 2006 Sergey Vlasov <vsu@altlinux.ru> 097-alt1
- New version (097).
- Dropped alt-compile-warnings patch (obsolete).
- Removed obsolete "--with klibc" build support from spec (upstream developers
  removed klibc support from udev 097).
- Removed obsolete "--with system_sysfs" build support from spec (udev does not
  use libsysfs for a long time).
- Tightened udev package dependency on libvolume_id due to unstable ABI.
- Removed tmpfs_options example with "helper" from udev.conf (the corresponding
  kernel patch was dropped long ago).
- Added alt-nogroup patch: vol_id: replace "nogroup" group name with "nobody"
  (partially fixes #9871).
- Replaced logger-path patch with alt-firmware-initlog patch: use /sbin/initlog
  instead of logger (which is in /usr/bin).
- Added alt-firmware-dirs patch: add /usr/lib/hotplug/firmware to firmware
  search path (to avoid regressions when firmware loading is switched from
  hotplug to udev).
- Updated udevd initscript:
  + fixed udevsettle race (#9881); removed broken workaround added in 091-alt3
  + add "-n" option to "mount --move" to fix duplication of /etc/mtab entries
    (#7758)
  + check that all required kernel features (/sys/class/mem/null/uevent,
    /sys/kernel/uevent_seqnum) are present before trying to start udevd
  + removed code for handling udevd started from hotplug (udev does not support
    this for a long time)
  + removed useless $mountcmd indirection from attach_pts_filesystem and
    attach_shm_filesystem
  + fixed /dev/null redirections in make_extra_nodes, removed /dev/null usage
    from places where /dev/null is not yet available
- Updated udev rules:
  + moved all WAIT_FOR_SYSFS rules to 05-udev-early.rules
  + moved firmware loading rules to 05-udev-early.rules, so that they are used
    before hotplug (previously both hotplug and udev were trying to load
    firmware; now all firmware loading is handled through udev)
  + removed useless rule which "renamed" eth* network interfaces to the same
    name
  + added joystick support to 60-persistent-input.rules
  + added crypto container support to 60-persistent-storage.rules
  + removed fuse rule (#9871)
  + removed /dev/tpm* rule with "tss" user/group (#9871)
  + removed /dev/ucm*, /dev/uverbs* rules with "rdma" group (#9871)
  + removed rules for SCSI scanners with "scanner" group (#9871)
  + removed /dev/nvram rule with "nvram" group (#9871)
  + replaced "tape" group with "disk", removed some rules which were setting
    the "tape" group for devices which already had the "disk" group from other
    rules (#9871)
  + removed "video" group from agpgart, DRI and framebuffer devices (now this
    group is used only for video capture devices)
- Create "video" group in %%pre (#9871).

* Mon Jul 10 2006 Anton Farygin <rider@altlinux.ru> 096-alt1
- new version

* Tue Jun 20 2006 Anton Farygin <rider@altlinux.ru> 094-alt1
- new version

* Thu Jun 01 2006 Anton Farygin <rider@altlinux.ru> 093-alt3
- fixed SUBSYSTEM and SYSFS errors in rules

* Tue May 30 2006 Anton Farygin <rider@altlinux.ru> 093-alt2
- fixed logger unmet

* Mon May 29 2006 Anton Farygin <rider@altlinux.ru> 093-alt1
- new version
- updated rules for new firmware loader

* Thu May 18 2006 Anton Farygin <rider@altlinux.ru> 092-alt1
- new version
- added lvm support (#7369, Nick S. Grechukh)

* Tue May 16 2006 Anton Farygin <rider@altlinux.ru> 091-alt3
- added workaround (sync) for tmpfs files creation race in initscript

* Sat May 06 2006 Anton Farygin <rider@altlinux.ru> 091-alt2
- package adopted to gear
- added patch from mainstream for creating parent directories for seqnum

* Fri Apr 28 2006 Anton Farygin <rider@altlinux.ru> 091-alt1
- new version

* Fri Apr 21 2006 Anton Farygin <rider@altlinux.ru> 090-alt2
- added sleep after udevtrigger

* Sun Apr 16 2006 Anton Farygin <rider@altlinux.ru> 090-alt1
- new version

* Fri Apr 14 2006 Anton Farygin <rider@altlinux.ru> 089.git20060414-alt0.3
- updated from git
- added udevsettle to initscript

* Wed Apr 12 2006 Anton Farygin <rider@altlinux.ru> 089-alt0.2
- path_id added

* Tue Apr 11 2006 Anton Farygin <rider@altlinux.ru> 089-alt0.1
- new version
- all rules changed for new udev policy

* Mon Mar 13 2006 Anton Farygin <rider@altlinux.ru> 0.77-alt3
- added rule for floppy devices creation (#9129)
- Zaptel devices removed from rules (#8753)
- Firmware loading fixed (thnx , lioka)
- fixed typo in initscript

* Tue Feb 21 2006 Anton Farygin <rider@altlinux.ru> 0.77-alt2
- fixed /dev/pts start and restart

* Wed Dec 14 2005 Anton Farygin <rider@altlinux.ru> 0.77-alt1
- new version
- use new regexp for initscript (#8061)
- fixed /dev premissions

* Tue Nov 15 2005 Anton Farygin <rider@altlinux.ru> 0.75-alt1
- next version

* Mon Sep 19 2005 Anton Farygin <rider@altlinux.ru> 0.70-alt1
- new version
- added rule for ttyACM
- fixed rule for /dev/tty (#8026)

* Wed Aug 31 2005 Anton Farygin <rider@altlinux.ru> 0.68-alt2
- fixed double /dev/pts mounting (#6974)

* Fri Aug 19 2005 Anton Farygin <rider@altlinux.ru> 0.68-alt1
- new version

* Mon Aug 08 2005 Anton Farygin <rider@altlinux.ru> 0.65-alt1
- updated to new version
- fixed typo in rules (#7394)

* Sun Jul 17 2005 Anton Farygin <rider@altlinux.ru> 0.63-alt2
- removed patch1 (included to mainstream)
- removed patch0 (use OPTIONS="ignore_device" for ACTION=="remove")
- requries to udev_static_addon added
- fixed rules for vizor (#7394)

* Wed Jul 13 2005 Anton Farygin <rider@altlinux.ru> 0.62-alt5
- fixed some bugs in rules

* Wed Jul 13 2005 Anton Farygin <rider@altlinux.ru> 0.62-alt4
- rules format updated

* Wed Jul 13 2005 Anton Farygin <rider@altlinux.ru> 0.62-alt3
- added rule for running scripts from hotplug.d and dev.d
- udev initscript remove hotplug execution from /proc/sys/kernel/hotplug

* Tue Jul 12 2005 Anton Farygin <rider@altlinux.ru> 0.62-alt2
- updated to 062

* Wed Mar 30 2005 Alexey Morozov <morozov@altlinux.org> 0.50-alt5
- Fixes for init script for empty and r/o /dev

* Tue Mar 29 2005 Alexey Morozov <morozov@altlinux.org> 0.50-alt4
- init script fixes
- udev lsb rules fixes (#6232, #6297, #6338, and probably #6337)
- built w/ syslog (#5850)
- possible integration w/ udev_static-*

* Sat Jan 22 2005 Alexey Morozov <morozov@altlinux.org> 0.50-alt3
- fixed typo in udevd.init (now service should start w/o complaining
  even if no devices in /etc/udev/devices can be found)
- udevd is forced to stop, even if it was launched not by init startup
  script
- added patch to skip unknown (new) options from udev.conf throughout
  C code (udevinfo, udev etc). Bug was reported by vk@.

* Fri Jan 14 2005 Alexey Morozov <morozov@altlinux.org> 0.50-alt2
- Use syslog by default (#5850)
- Added udevinfo prints patch from ML
- Preliminary support of modules_lookup
- Actual use of tmpfs_options
- Added directory %_sysconfdir/udev/devices as a workaround for
  "missing devices" problem. One can create required device inodes
  with /sbin/MAKEDEV -d /etc/udev/devices <devname>, and all these
  inodes will be copied as is to /dev upon udev startup.
- DO_TRADITIONAL and PREFER_TRADITIONAL removed from cd-names.sh
  Traditional names if needed now should be specified right in udev rules

* Tue Jan  4 2005 Alexey Morozov <morozov@altlinux.org> 0.50-alt1
- New version (0.50)

* Tue Dec 28 2004 Alexey Morozov <morozov@altlinux.org> 0.46-alt3
- extended modifiers are fixed [hopefully]
- ide-names.sh replaced by drive-names.sh which can be used for SCSI disks (only sd*)
  as well as as for IDE drives (either IDE hard disks, CD-ROMs, or IDE floppies)

* Tue Dec 14 2004 Alexey Morozov <morozov@altlinux.org> 0.46-alt2
- Fixed CD-ROMs / CD-RWs etc permissions

* Tue Dec 14 2004 Alexey Morozov <morozov@altlinux.org> 0.46-alt1
- version 0.46 (046)
- service init script greatly improved. Now it passes multiple start/stop etc cycles almost seamlessly
- permissions and device naming rules also improved (mostly taked from Mdk w/ certain Debian stuff
  and home-made ide-names.sh and cd-names.sh). Device naming rules are still subject for improvement and
  bugfixing though...
- Added patches for %%N and %%U rules keys (see 'man 8 udev' for description)
- Fixes for %%e
- TODO: write a SCSI-oriented companion for ide-names.sh. Contrubutors are welcome ;-)

* Thu Nov 11 2004 Alexey Morozov <morozov@altlinux.org> 0.43-alt1
- New version (0.43)
- Spec and patches are re-worked a bit (now it can be correctly build w/ and w/o
  system sysfs)

* Thu Sep 16 2004 Alexey Morozov <morozov@altlinux.org> 0.32-alt1
- Initial build for ALT Linux

